Module blaxel.core.client.models.resource_trace
===============================================

Classes
-------

`ResourceTrace(duration: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>, has_error: blaxel.core.client.types.Unset | bool = <blaxel.core.client.types.Unset object>, start_time: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, status_code: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>, trace_id: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>)`
:   Log for a resource deployment (eg. model deployment, function deployment)
    
    Attributes:
        duration (Union[Unset, int]): Duration in nanoseconds
        has_error (Union[Unset, bool]): Has error
        start_time (Union[Unset, str]): The timestamp of the log
        status_code (Union[Unset, int]): Status code
        trace_id (Union[Unset, str]): Trace ID of the log
    
    Method generated by attrs for class ResourceTrace.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `duration: blaxel.core.client.types.Unset | int`
    :

    `has_error: blaxel.core.client.types.Unset | bool`
    :

    `start_time: blaxel.core.client.types.Unset | str`
    :

    `status_code: blaxel.core.client.types.Unset | int`
    :

    `trace_id: blaxel.core.client.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :